@@ -1,5 +1,5 @@
 /*[License]
-    - Author: Molese <molese@protonmail.com> 2022
+    - Author: Molese <molese@engineer.com> 2022
 
     Licensed under either of
 
@@ -14,16 +14,19 @@ use {
     std::{env, process},
 };
 
+macro_rules! die {
+    ($($arg:tt)*) => (
+        eprintln!("Fatal: {}!", $($arg)*);
+    )
+}
+
 fn main() {
-    /* `unwrap_or_else` for non-panic error handling. Using an anonymous function. */
     let config: Config = Config::new(env::args()).unwrap_or_else(|err: &str| {
-        /* printing the error to the standard error instead of standard output */
-        eprintln!("Fatal: {}!", err);
-        process::exit(0x0100); /* To exit neatly without any other info spewed out */
+        die!(err);
+        process::exit(0x0100);
     });
 
-    /* `if let` is used to check if an `Err` type is actually returned. */
     if let Err(err) = run(config) {
-        eprintln!("Fatal: {}!", err);
+        die!(err);
     }
 }
